<?php
/*
Plugin Name: URL Listleyici
Plugin URI: https://mimozabilisim.com/kullanisli-wordpress-eklentileri/
Description: WordPress sitenizin tüm içerik URL'lerini listeler ve arama yapmanızı sağlar
Version: 1.0
Author: Onur Kalafat
Author URI: https://mimozabilisim.com/
Text Domain: url-listleyici
Domain Path: /languages
*/

// Güvenlik kontrolü
if (!defined('ABSPATH')) {
    exit;
}

// Eklenti sınıfı
class URL_Listleyici {
    
    public function __construct() {
        add_action('admin_menu', array($this, 'admin_menu_ekle'));
        add_action('admin_enqueue_scripts', array($this, 'admin_styles'));
        add_action('plugins_loaded', array($this, 'plugin_yukle'));
    }

    // Dil dosyalarını yükle
    public function plugin_yukle() {
        load_plugin_textdomain('url-listleyici', false, dirname(plugin_basename(__FILE__)) . '/languages');
    }

    // Admin menüsüne ekle
    public function admin_menu_ekle() {
        add_menu_page(
            __('URL Listleyici', 'url-listleyici'),
            __('URL Listleyici', 'url-listleyici'),
            'manage_options',
            'url-listleyici',
            array($this, 'admin_sayfa_icerigi'),
            'dashicons-list-view'
        );
    }

    // Admin styles ve scripts
    public function admin_styles($hook) {
        if ($hook != 'toplevel_page_url-listleyici') {
            return;
        }
        wp_enqueue_style('url-listleyici-style', plugins_url('css/admin-style.css', __FILE__));
        wp_enqueue_script('url-listleyici-script', plugins_url('js/admin-script.js', __FILE__), array('jquery'), '1.0', true);
    }

    // URL'leri topla
    private function urlleri_topla() {
        $urls = array();
        
        // Sayfalar
        $sayfalar = get_pages();
        foreach ($sayfalar as $sayfa) {
            $url = parse_url(get_page_link($sayfa->ID), PHP_URL_PATH);
            $urls['sayfalar'][] = array(
                'baslik' => $sayfa->post_title,
                'url' => $url
            );
        }
        
        // Kategoriler
        $kategoriler = get_categories(array('hide_empty' => false));
        foreach ($kategoriler as $kategori) {
            $url = parse_url(get_category_link($kategori->term_id), PHP_URL_PATH);
            $urls['kategoriler'][] = array(
                'baslik' => $kategori->name,
                'url' => $url
            );
        }
        
        // Yazılar
        $yazilar = get_posts(array('posts_per_page' => -1));
        foreach ($yazilar as $yazi) {
            $url = parse_url(get_permalink($yazi->ID), PHP_URL_PATH);
            $urls['yazilar'][] = array(
                'baslik' => $yazi->post_title,
                'url' => $url
            );
        }
        
        // Portfolio sayfaları (eğer varsa)
        if (post_type_exists('portfolio')) {
            $portfolio_sayfalari = get_posts(array('post_type' => 'portfolio', 'posts_per_page' => -1));
            foreach ($portfolio_sayfalari as $portfolio) {
                $url = parse_url(get_permalink($portfolio->ID), PHP_URL_PATH);
                $urls['portfolio'][] = array(
                    'baslik' => $portfolio->post_title,
                    'url' => $url
                );
            }
        }
        
        return $urls;
    }

    // Admin sayfası içeriği
    public function admin_sayfa_icerigi() {
        if (!current_user_can('manage_options')) {
            wp_die(__('Bu sayfaya erişim izniniz bulunmuyor.', 'url-listleyici'));
        }
        
        $urls = $this->urlleri_topla();
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            
            <div class="arama-kutusu">
                <input type="text" id="urlArama" placeholder="<?php _e('Aramak istediğiniz kelimeyi yazın...', 'url-listleyici'); ?>" />
            </div>
            
            <div class="url-listesi-container">
                <!-- Sayfalar -->
                <div class="url-section">
                    <h2><?php _e('Sayfalar', 'url-listleyici'); ?></h2>
                    <table class="wp-list-table widefat fixed striped">
                        <thead>
                            <tr>
                                <th><?php _e('Sayfa Adı', 'url-listleyici'); ?></th>
                                <th><?php _e('URL', 'url-listleyici'); ?></th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($urls['sayfalar'] as $sayfa): ?>
                            <tr>
                                <td><?php echo esc_html($sayfa['baslik']); ?></td>
                                <td><?php echo esc_html($sayfa['url']); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>

                <!-- Kategoriler -->
                <div class="url-section">
                    <h2><?php _e('Kategoriler', 'url-listleyici'); ?></h2>
                    <table class="wp-list-table widefat fixed striped">
                        <thead>
                            <tr>
                                <th><?php _e('Kategori Adı', 'url-listleyici'); ?></th>
                                <th><?php _e('URL', 'url-listleyici'); ?></th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($urls['kategoriler'] as $kategori): ?>
                            <tr>
                                <td><?php echo esc_html($kategori['baslik']); ?></td>
                                <td><?php echo esc_html($kategori['url']); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>

                <!-- Yazılar -->
                <div class="url-section">
                    <h2><?php _e('Yazılar', 'url-listleyici'); ?></h2>
                    <table class="wp-list-table widefat fixed striped">
                        <thead>
                            <tr>
                                <th><?php _e('Yazı Başlığı', 'url-listleyici'); ?></th>
                                <th><?php _e('URL', 'url-listleyici'); ?></th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($urls['yazilar'] as $yazi): ?>
                            <tr>
                                <td><?php echo esc_html($yazi['baslik']); ?></td>
                                <td><?php echo esc_html($yazi['url']); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>

                <?php if (isset($urls['portfolio'])): ?>
                <!-- Portfolio -->
                <div class="url-section">
                    <h2><?php _e('Portfolio', 'url-listleyici'); ?></h2>
                    <table class="wp-list-table widefat fixed striped">
                        <thead>
                            <tr>
                                <th><?php _e('Portfolio Başlığı', 'url-listleyici'); ?></th>
                                <th><?php _e('URL', 'url-listleyici'); ?></th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($urls['portfolio'] as $portfolio): ?>
                            <tr>
                                <td><?php echo esc_html($portfolio['baslik']); ?></td>
                                <td><?php echo esc_html($portfolio['url']); ?></td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                <?php endif; ?>
            </div>
        </div>
        <?php
    }
}

// Eklentiyi başlat
new URL_Listleyici();

// Aktivasyon kancası
register_activation_hook(__FILE__, 'url_listleyici_aktivasyon');
function url_listleyici_aktivasyon() {
    // Aktivasyon işlemleri
}

// CSS dosyası oluştur
function url_listleyici_css_olustur() {
    $css_dizini = plugin_dir_path(__FILE__) . 'css';
    if (!file_exists($css_dizini)) {
        mkdir($css_dizini, 0755, true);
    }
    
    $css_dosyasi = $css_dizini . '/admin-style.css';
    if (!file_exists($css_dosyasi)) {
        $css_content = "
.url-listesi-container {
    margin-top: 20px;
}

.url-section {
    margin-bottom: 30px;
}

.url-section h2 {
    margin-bottom: 15px;
}

.wp-list-table th,
.wp-list-table td {
    padding: 8px 10px;
}

.arama-kutusu {
    margin: 20px 0;
    padding: 15px;
    background: #fff;
    border: 1px solid #ccd0d4;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
}

.arama-kutusu input {
    width: 100%;
    padding: 8px;
    font-size: 14px;
    border: 1px solid #ddd;
    border-radius: 4px;
}

.arama-sonucu {
    background-color: #f7fcfe !important;
}

.arama-sonucu td {
    font-weight: bold;
}
";
        file_put_contents($css_dosyasi, $css_content);
    }
}

// JavaScript dosyası oluştur
function url_listleyici_js_olustur() {
    $js_dizini = plugin_dir_path(__FILE__) . 'js';
    if (!file_exists($js_dizini)) {
        mkdir($js_dizini, 0755, true);
    }
    
    $js_dosyasi = $js_dizini . '/admin-script.js';
    if (!file_exists($js_dosyasi)) {
        $js_content = "
jQuery(document).ready(function($) {
    $('#urlArama').on('keyup', function() {
        var aramaMetni = $(this).val().toLowerCase();
        
        if (aramaMetni.length > 0) {
            $('.url-section table tbody tr').each(function() {
                var baslik = $(this).find('td:first').text().toLowerCase();
                var url = $(this).find('td:last').text().toLowerCase();
                
                if (baslik.indexOf(aramaMetni) > -1 || url.indexOf(aramaMetni) > -1) {
                    $(this).show();
                    $(this).addClass('arama-sonucu');
                } else {
                    $(this).hide();
                    $(this).removeClass('arama-sonucu');
                }
            });
            
            $('.url-section').each(function() {
                var gorunurSatirlar = $(this).find('tbody tr:visible').length;
                if (gorunurSatirlar > 0) {
                    $(this).show();
                } else {
                    $(this).hide();
                }
            });
        } else {
            $('.url-section table tbody tr').show().removeClass('arama-sonucu');
            $('.url-section').show();
        }
    });
});
";
        file_put_contents($js_dosyasi, $js_content);
    }
}

// Aktivasyon sırasında CSS ve JS dosyalarını oluştur
register_activation_hook(__FILE__, function() {
    url_listleyici_css_olustur();
    url_listleyici_js_olustur();
});